@@ -53,14 +53,31 @@ if [ $START = TRUE ]; then
     echo "$0: Error, DIALOGMODE is not defined"
     exit 2
   fi
+  if [ "x$SUPERMODAL" = "x" ]; then
+    echo "$0: Error, SUPERMODAL is not defined"
+    exit 2
+  fi
 
-  $LAUNCHWRAPPER start "$SVC" $PROG \
+# _NET_WM_PING ping handler
+export MB_HUNG_APP_HANDLER='/usr/bin/hn-hung-app-handler'
+export MB_AGGRESSIVE_PING=1
+
+  $LAUNCHWRAPPER_NICE start "$SVC" $PROG \
       -theme $MBTHEME \
       -use_titlebar $TITLEBAR \
       -use_desktop_mode $DESKTOPMODE \
       -use_lowlight $LOWLIGHT \
       -use_cursor $SHOWCURSOR \
-      -use_dialog_mode $DIALOGMODE
+      -use_dialog_mode $DIALOGMODE \
+      -use_super_modal $SUPERMODAL
 else
-  $LAUNCHWRAPPER stop "$SVC" $PROG
+  # dsmetool wants identical arguments for stopping
+  $LAUNCHWRAPPER_NICE stop "$SVC" $PROG \
+      -theme $MBTHEME \
+      -use_titlebar $TITLEBAR \
+      -use_desktop_mode $DESKTOPMODE \
+      -use_lowlight $LOWLIGHT \
+      -use_cursor $SHOWCURSOR \
+      -use_dialog_mode $DIALOGMODE \
+      -use_super_modal $SUPERMODAL
 fi
